from subprocess import check_output

def get_motherboard():
    product = check_output('wmic baseboard get product').decode()
    product = product[7:len(product)]
    product = product.strip()
    return product

def get_manufacturer():
    manufacturer = check_output('wmic baseboard get Manufacturer').decode()
    manufacturer = manufacturer[13:len(manufacturer)]
    manufacturer = manufacturer.strip()
    return manufacturer


from setuptools import find_packages, setup
setup(
    name='hwinfos',
    packages=find_packages(include=['hwinfos']),
    version='0.1.0',
    description='Get PC hardware info for Windows OS',
    author='R3FL3X',
    license='MIT',
    test_suite='tests',
    setup_requires=['pytest-runner'],
    tests_require=['pytest'],
    author_email='christos.daglaroglou@gmail.com',
    classifiers=[
        'Programming Language :: Python',
        'Operating System :: Microsoft :: Windows',
    ]
)